@@ -4,16 +4,25 @@ import os
 from command.initialize import Initialize
 from command.collect import Collect
 from command.prepare import Prepare
+from dotenv import load_dotenv, find_dotenv
 app=Flask(__name__)
 CORS(app)
+load_dotenv(find_dotenv())
 
+AWS_ACCESS_KEY_ID = os.environ.get("AWS_ACCESS_KEY_ID")
+AWS_SECRET_ACCESS_KEY = os.environ.get("AWS_SECRET_ACCESS_KEY")
 @app.route('/')
 def root_route():
     return 'Hello World'
 
 @app.route('/newPost', methods=['POST'])
 def initialize():
+    # clear all the data inside the VM
+    os.system('./tools/shell/jobClearJSON.sh')
+    # get the input
     input=request.json
+    print(AWS_ACCESS_KEY_ID)
+    print(AWS_SECRET_ACCESS_KEY)
 
     # make class instance
     initialize_command=Initialize(input['region'], input['user_id'],
@@ -22,16 +31,19 @@ def initialize():
     # execute class function
     initialize_command.validate_input()
     initialize_command.check_identity()
-    initialize_command.send_request_to_s3()
-    requestID=initialize_command.make_request()
+    initialize_command.send_request_to_s3(AWS_ACCESS_KEY_ID,AWS_SECRET_ACCESS_KEY)
+    requestID=initialize_command.make_request(AWS_ACCESS_KEY_ID,AWS_SECRET_ACCESS_KEY)
     print('The requestID is:', requestID)
+    # print parameter inside class
     initialize_command.print_class_parameter()
+    # get account id to initialize collect class
+    account_id=initialize_command.get_account_id()
 
     # get the region
     regions=initialize_command.get_region()
     for region in regions:
         # initialize class
-        collect_command = Collect(region)
+        collect_command = Collect(region,account_id)
 
         # call command functions
         collect_command.get_lambda_list()
@@ -75,9 +87,13 @@ def initialize():
         collect_command.list_cognito_identity_pool()
         collect_command.get_s3_bucket_policy_status()
         collect_command.describe_cognito_identity_pools()
+        collect_command.list_sns_tag()
+        collect_command.list_sfn_tag()
+        collect_command.list_ddb_tag()
+        collect_command.list_s3_tag()
+        collect_command.list_lambda_tag()
 
     # initialize a class
-    account_id=initialize_command.get_account_id()
     for i in range(len(regions)):
         prepare_command = Prepare(regions[i], account_id)
 
@@ -105,8 +121,8 @@ def initialize():
         # EXPORT INTO JSON FILE
         if(i==len(regions)-1):
             prepare_command.exportToJSON()
-            prepare_command.export_JSON_to_S3()
-            prepare_command.write_to_dynamoDB(str(requestID))
+            prepare_command.export_JSON_to_S3(AWS_ACCESS_KEY_ID,AWS_SECRET_ACCESS_KEY)
+            prepare_command.write_to_dynamoDB(str(requestID),AWS_ACCESS_KEY_ID,AWS_SECRET_ACCESS_KEY)
     return {  
         'status': 'Success',
         'code': 200,
@@ -115,19 +131,27 @@ def initialize():
 
 @app.route('/update',methods=['POST'])
 def update():
+    # clear all data inside VM
+    os.system('./tools/shell/jobClearJSON.sh')
+    # get the input from http
     input=request.json
     print(input)
+    # initialize the Initialize Class
     initialize_command=Initialize('','','','','','')
-    initialize_command.process_requestID(input['requestID'])
-    initialize_command.get_credentials()
+    # execute the sequence for update
+    initialize_command.process_requestID(input['requestID'],AWS_ACCESS_KEY_ID,AWS_SECRET_ACCESS_KEY)
+    initialize_command.update_ddb_status(input['requestID'],AWS_ACCESS_KEY_ID,AWS_SECRET_ACCESS_KEY)
+    initialize_command.get_credentials(AWS_ACCESS_KEY_ID,AWS_SECRET_ACCESS_KEY)
     initialize_command.check_identity()
+    # print the parameter inside Initialize Class
     initialize_command.print_class_parameter()
-
+    # get account_id 
+    account_id=initialize_command.get_account_id()
     # get the region
     regions=initialize_command.get_region()
     for region in regions:
         # initialize class
-        collect_command = Collect(region)
+        collect_command = Collect(region,account_id)
 
         # call command functions
         collect_command.get_lambda_list()
@@ -171,9 +195,13 @@ def update():
         collect_command.list_cognito_identity_pool()
         collect_command.get_s3_bucket_policy_status()
         collect_command.describe_cognito_identity_pools()
+        collect_command.list_sns_tag()
+        collect_command.list_sfn_tag()
+        collect_command.list_ddb_tag()
+        collect_command.list_s3_tag()
+        collect_command.list_lambda_tag()
 
     # initialize a class
-    account_id=initialize_command.get_account_id()
     for i in range(len(regions)):
         prepare_command = Prepare(regions[i], account_id)
 
@@ -201,28 +229,13 @@ def update():
         # EXPORT INTO JSON FILE
         if(i==len(regions)-1):
             prepare_command.exportToJSON()
-            prepare_command.export_JSON_to_S3()
-            prepare_command.write_to_dynamoDB(str(input['requestID']))
+            prepare_command.export_JSON_to_S3(AWS_ACCESS_KEY_ID,AWS_SECRET_ACCESS_KEY)
+            prepare_command.write_to_dynamoDB(str(input['requestID']),AWS_ACCESS_KEY_ID,AWS_SECRET_ACCESS_KEY)
     return {  
         'status': 'Success',
         'code': 200,
         'message': 'Succeed updating metadata file'
     }
 
-@app.route('/request',methods=['DELETE'])
-def clearJSONMetadata():
-    try:
-        os.system('./jobClearJSON.sh')
-    except:
-        return{
-            'status': 'Error',
-            'code': 500,
-            'message':'Bad Request Error'
-        }
-    return {  
-        'status': 'Success',
-        'code': 200,
-        'message': 'Succeed erasing metadata file'
-    }
 if __name__ == '__main__':
     app.run(host='0.0.0.0', port=9000, debug=True)
\ No newline at end of file
